slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPSetExtract

Specifies the extraction strategy to be used.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPSetExtract(PEP pep,PEPExtract extract)

Logically Collective on pep

### Input Parameters

| pep | - the eigensolver context
| extract | - extraction strategy

### Options Database Keys

| -pep_extract <type> | - extraction type, one of <none,norm,residual,structured>

### See Also

PEPGetExtract()

### Level

intermediate

### Location

src/pep/interface/pepopts.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages